body { padding-top: 70px; }

.word-break{
    word-break: break-all;
}

.fix-float{
    width: 100%;
    height: 0;
    clear: both;
}

.div-hover:hover{
    background-color: #f6f6f6;
}

.div-as-tablerow{
    border: 1px solid #f6f6f6;
    padding-top: 5px;
    padding-bottom: 5px;
    margin-right: 0 !important;
    margin-left: 0 !important;
}

.strip {
    background-color: #f6f6f6;
}

.inline{
    display: inline-block;
}

.margin-top {
    margin-top: 10px;
}

.inline {
    display: inline;
}

.hidden {
    display: none;
}

.modal-dialog{
    width: 1000px;
}

.modal-content {
    width: 1000px;
    margin-left: -200px;
}
.brand-subtitle{
    color: #999;
    font-weight: 500;
    font-size: 10px;
    text-transform: capitalize;
}

.rickshaw_graph svg {
    margin-top: 20px;
    margin-bottom: 5px;
}

.top-border{border-top:1px solid #999999;}
.top-padding{padding-top:1em;}

.btn-close-graph{margin-left: 4px;}

.scrollable{overflow-y: auto;max-height: 600px;padding-left: 15px;padding-right: 15px;}

.overflow-x-auto{overflow-x: auto;}

.max-height-800{max-height: 800px;}

#reboot-container{margin:0px 0px 7px 20px;}

.inline-block{display:inline-block;}
