{% extends 'console/metrics_base.html' %}

{% block extra_head %}
    {{ block.super }}
    <script src="{{ STATIC_URL }}console/js/jquery.cookie.js"></script>
{% endblock %}

{% block content %}

    <h3>{{ subject }} {{ metric_type }} Metrics</b></h3>
    {% include "console/metrics_container.html" %}
{% endblock %}


{% block footer_js %}
    {{ block.super }}
    <script>
        var url = '{{ url }}';
        var dates = {{dates|safe}};
    </script>
    <script src="{{ STATIC_URL }}console/js/metric_detail.js"></script>
{% endblock %}
